Use sRGB encoded reference values for 8-bit Display P3 tests

Per EGL_EXT_gl_colorspace_display_p3 spec, Display P3 assumes
sRGB transfer function. So use the reference values computed
in sRGB space for 8-bit Display P3 tests, instead of linear ones.

Components: AOSP
VK-GL-CTS issue: 1384

Affects:
dEQP-EGL.functional.wide_color.pbuffer_8888_colorspace_p3
dEQP-EGL.functional.wide_color.window_8888_colorspace_p3

Change-Id: I77cf0f84b3189ce4e64f28a83d771b21eccd9214
diff --git a/modules/egl/teglWideColorTests.cpp b/modules/egl/teglWideColorTests.cpp
index 2bdaf22..dfc46b9 100644
--- a/modules/egl/teglWideColorTests.cpp
+++ b/modules/egl/teglWideColorTests.cpp
@@ -864,9 +864,10 @@
 	}
 	else
 	{
-		// Apply sRGB transfer function when colorspace is sRGB and pixel component
-		// size is 8 bits (which is why we are here in expectedUint8).
-		if (m_colorSpace == EGL_GL_COLORSPACE_SRGB_KHR)
+		// Apply sRGB transfer function when colorspace is sRGB or Display P3 and
+		// pixel component size is 8 bits (which is why we are here in expectedUint8).
+		if (m_colorSpace == EGL_GL_COLORSPACE_SRGB_KHR ||
+				m_colorSpace == EGL_GL_COLORSPACE_DISPLAY_P3_EXT)
 		{
 			float srgbReference;